@@ -1,12 +1,11 @@
 ---------------------------------------------------------------------------
+--- Widget module for awful
+--
 -- @author Julien Danjou &lt;julien@danjou.info&gt;
 -- @copyright 2008-2009 Julien Danjou
--- @release v3.5.8
+-- @classmod awful.widget
 ---------------------------------------------------------------------------
 
---- Widget module for awful
--- awful.widget
-
 return
 {
     taglist = require("awful.widget.taglist");
@@ -18,6 +17,10 @@ return
     graph = require("awful.widget.graph");
     layoutbox = require("awful.widget.layoutbox");
     textclock = require("awful.widget.textclock");
+    keyboardlayout = require("awful.widget.keyboardlayout");
+    watch = require("awful.widget.watch");
+    only_on_screen = require("awful.widget.only_on_screen");
+    clienticon = require("awful.widget.clienticon");
 }
 
 -- vim: filetype=lua:expandtab:shiftwidth=4:tabstop=8:softtabstop=4:textwidth=80
